Summary:        Library for solving packages and reading repositories
Name:           libsolv
Version:        0.7.24
Release:        4%{?dist}
License:        BSD
URL:            https://github.com/openSUSE/libsolv
Source0:        https://github.com/openSUSE/libsolv/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake gcc-c++ ninja-build rpm-devel zlib-devel libxml2-devel xz-devel bzip2-devel libzstd-devel

# example/solv, a tool for demoing, not need actually.
Obsoletes: libsolv-demo <= %{version}

%description
This is libsolv, a free package dependency solver using a satisfiability 
algorithm.

The code is based on two major, but independent, blocks:

1. Using a dictionary approach to store and retrieve package and dependency 
information in a fast and space efficient manner.
2. Using satisfiability, a well known and researched topic, for resolving 
package dependencies.
The sat-solver code has been written to aim for the newest packages, record 
the decision tree to provide introspection, and also provides the user with 
suggestions on how to deal with unsolvable problems. It also takes advantage 
of repository storage to minimize memory usage.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release} rpm-devel

%description devel
Development files for %{name}.

%package tools
Summary:        Package dependency solver tools
Requires:       %{name} = %{version}-%{release} findutils

%description tools
Package dependency solver tools.

%package demo
Summary:        Applications demoing the %{name} library
Requires:       %{name} = %{version}-%{release} curl gnupg2

%description demo
Applications demoing the %{name} library.

%package -n perl-solv
Summary:        Perl bindings for the %{name} library
BuildRequires:  swig perl-devel perl-generators
Requires:       %{name} = %{version}-%{release}

%description -n perl-solv
Perl bindings for the %{name} library.

%package -n python3-solv
Summary:        Python bindings for the %{name} library
BuildRequires:  swig python3-devel
Requires:       %{name} = %{version}-%{release}
Provides:       python%{python3_version}-solv = %{version}-%{release}
Provides:       python-solv = %{version}-%{release}

%description -n python3-solv
Python bindings for the %{name} library.

Python 3 version.

%prep
%autosetup -p1

%build
%cmake -GNinja                                            \
  -DFEDORA=1                                              \
  -DENABLE_RPMDB=ON                                       \
  -DENABLE_RPMDB_BYRPMHEADER=ON                           \
  -DENABLE_RPMDB_LIBRPM=ON                                \
  -DENABLE_RPMPKG_LIBRPM=ON                               \
  -DENABLE_RPMMD=ON                                       \
  -DENABLE_COMPS=ON                                       \
  -DENABLE_APPDATA=ON                                     \
  -DUSE_VENDORDIRS=ON                                     \
  -DWITH_LIBXML2=ON                                       \
  -DENABLE_LZMA_COMPRESSION=ON                            \
  -DENABLE_BZIP2_COMPRESSION=ON                           \
  -DENABLE_ZSTD_COMPRESSION=ON                            \
  -DENABLE_ZCHUNK_COMPRESSION=OFF                         \
  -DWITH_SYSTEM_ZCHUNK=OFF                                \
  -DENABLE_HELIXREPO=ON                                   \
  -DENABLE_SUSEREPO=ON                                    \
  -DENABLE_DEBIAN=ON                                      \
  -DENABLE_ARCHREPO=ON                                    \
  -DMULTI_SEMANTICS=ON                                    \
  -DENABLE_COMPLEX_DEPS=ON                                \
  -DENABLE_CONDA=ON                                       \
  -DENABLE_PERL=ON                                        \
  -DENABLE_RUBY=OFF                                       \
  -DENABLE_PYTHON=ON                                      \
  -DPYTHON_EXECUTABLE=%{__python3}                        \
  %{nil}
%cmake_build

%install
%cmake_install

%check
%ctest

export PYTHONPATH=%{buildroot}%{python3_sitearch}
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%__python3 -c 'import solv'

%files
%license LICENSE*
%doc README
%{_libdir}/%{name}.so.*
%{_libdir}/%{name}ext.so.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/%{name}ext.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}ext.pc
%{_includedir}/solv/
%dir %{_datadir}/cmake/Modules/
%{_datadir}/cmake/Modules/FindLibSolv.cmake
%{_mandir}/man3/%{name}*.3*

%files tools
%{_bindir}/*
%{_mandir}/man1/*

%files -n perl-solv
%{perl_vendorarch}/solv.pm
%{perl_vendorarch}/solv.so

%files -n python3-solv
%{python3_sitearch}/_solv.so
%{python3_sitearch}/solv.py
%{python3_sitearch}/__pycache__/solv.*

%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.24-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.24-3
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 15 2023 Shuo Wang <abushwang@tencent.com> - 0.7.24-2
- update cmake config for dnf 4.14.0 build fail

* Tue Jul 11 2023 Yi Lin <nilusyi@tencent.com> - 0.7.24-1
- upgrade to 0.7.24

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.22-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.22-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Apr 29 2022 Xun Zhong <victorzhong@tencent.com> - 0.7.22-1
- Initial build
